@@ -100,9 +100,6 @@ SKIPPED_IMAGES = {
     ],
     'centos+source': [
         "ovsdpdk",
-        # TODO(mandre) remove after fixing
-        # https://bugs.launchpad.net/kolla/+bug/1774123
-        "sensu-base",
         # TODO(jeffrey4l): remove tripleo-ui when following bug is fixed
         # https://bugs.launchpad.net/tripleo/+bug/1744215
         "tripleo-ui"
@@ -713,7 +710,12 @@ class KollaWorker(object):
         self.maintainer = conf.maintainer
 
         docker_kwargs = docker.utils.kwargs_from_env()
-        self.dc = docker.APIClient(version='auto', **docker_kwargs)
+        try:
+            self.dc = docker.APIClient(version='auto', **docker_kwargs)
+        except docker.errors.DockerException as e:
+            self.dc = None
+            if not conf.template_only:
+                raise e
 
     def _get_images_dir(self):
         possible_paths = (
@@ -889,7 +891,7 @@ class KollaWorker(object):
             template = env.get_template(tpl_path)
             if self.conf.template_override:
                 tpl_dict = self._merge_overrides(self.conf.template_override)
-                template_name = os.path.basename(tpl_dict.keys()[0])
+                template_name = os.path.basename(list(tpl_dict.keys())[0])
                 values['parent_template'] = template
                 env = jinja2.Environment(  # nosec: not used to render HTML
                     loader=jinja2.DictLoader(tpl_dict))
